@@ -1,6 +1,5 @@
-use Moose;
-use Moose::Util::TypeConstraints;
-
+# This is only test file for snippets expansion
+# Press TAB after each word to expand the snippet
 BUILD
 DEMOLISH
 after
